@@ -824,7 +824,7 @@ static gboolean
 gst_flac_parse_handle_vorbiscomment (GstFlacParse * flacparse,
     GstBuffer * buffer)
 {
-  flacparse->tags = gst_tag_list_from_vorbiscomment_buffer (buffer,
+  flacparse->tags = gst_hack_tag_list_from_vorbiscomment_buffer (buffer,
       GST_BUFFER_DATA (buffer), 4, NULL);
 
   if (flacparse->tags == NULL) {
@@ -1044,6 +1044,27 @@ push_headers:
 
   /* push header buffers; update caps, so when we push the first buffer the
    * negotiated caps will change to caps that include the streamheader field */
+  while (flacparse->headers) {
+    GstBuffer *buf = GST_BUFFER (flacparse->headers->data);
+    GstFlowReturn ret;
+    GstBaseParseFrame frame;
+
+    flacparse->headers =
+        g_list_delete_link (flacparse->headers, flacparse->headers);
+    buf = gst_buffer_make_metadata_writable (buf);
+    gst_buffer_set_caps (buf,
+        GST_PAD_CAPS (GST_BASE_PARSE_SRC_PAD (GST_BASE_PARSE (flacparse))));
+
+    /* init, set and give away frame */
+    gst_base_parse_frame_init (&frame);
+    frame.buffer = buf;
+    frame.overhead = -1;
+    ret = gst_base_parse_push_frame (GST_BASE_PARSE (flacparse), &frame);
+    if (ret != GST_FLOW_OK) {
+      res = FALSE;
+      break;
+    }
+  }
   g_list_foreach (flacparse->headers, (GFunc) gst_mini_object_unref, NULL);
   g_list_free (flacparse->headers);
   flacparse->headers = NULL;
