@@ -314,7 +314,7 @@ tag_list_from_vorbiscomment_packet (ogg_packet * packet,
   GST_BUFFER_DATA (buf) = (guint8 *) packet->packet;
   GST_BUFFER_SIZE (buf) = packet->bytes;
 
-  list = gst_tag_list_from_vorbiscomment_buffer (buf, id_data, id_data_length,
+  list = gst_hack_tag_list_from_vorbiscomment_buffer (buf, id_data, id_data_length,
       &encoder);
 
   if (!list) {
