@@ -11,6 +11,13 @@
 
 #include <gst/base/gstbitreader.h>
 
+#if !GST_CHECK_VERSION(0,10,33)
+GstTagList *gst_hack_tag_list_from_vorbiscomment_buffer(const GstBuffer *buffer,
+		const guint8 *id_data,
+		const guint id_data_length,
+		gchar **vendor_string);
+#endif
+
 #if !GST_CHECK_VERSION(0,10,28)
 #define GST_FLOW_CUSTOM_SUCCESS_1 101
 #endif
